// src/util.ts
import { isAbsolute, normalize, resolve } from "pathe";
function resolveReplacement(replacement, baseDir = "./") {
  return isAbsolute(replacement) ? normalize(replacement) : `${resolve(baseDir)}/${normalize(replacement)}`;
}
function resolveAliasArr(aliasArr, baseDir) {
  const resolved = [];
  for (const { find, replacement } of aliasArr) {
    resolved.push({
      find,
      replacement: resolveReplacement(replacement, baseDir)
    });
  }
  return resolved;
}
function resolveAliasMap(aliasMap, baseDir) {
  const resolved = {};
  for (const find of Object.keys(aliasMap)) {
    const replacement = aliasMap[find];
    resolved[find] = resolveReplacement(replacement, baseDir);
  }
  return resolved;
}
function resolveAliases(aliases, baseDir) {
  return Array.isArray(aliases) ? resolveAliasArr(aliases, baseDir) : resolveAliasMap(aliases, baseDir);
}

// src/index.ts
var src_default = (aliases, options) => {
  const { baseDir } = options || {};
  return {
    name: "vite-plugin-easy-resolve-alias",
    config: () => ({
      resolve: {
        alias: resolveAliases(aliases, baseDir)
      }
    })
  };
};
export {
  src_default as default
};
